@@ -12,11 +12,18 @@ from dexom_python.default_parameter_values import DEFAULT_VALUES
 def write_solution(model, solution, threshold, filename='imat_sol.csv'):
     """
     Writes an optimize solution as a txt file. The solution is written in a column format
+
     Parameters
     ----------
+    model: cobra.Model
     solution: cobra.Solution
     threshold: float
     filename: str
+
+    Returns
+    ----------
+    solution: cobra.Solution
+    solution_binary: numpy.array
     """
     tol = model.solver.configuration.tolerances.feasibility
     solution_binary = (np.abs(solution.fluxes) >= threshold-tol).values.astype(int)
@@ -63,8 +70,13 @@ def read_solution(filename, model=None, reaction_weights=None, solution_index=0,
             objective_value = float(reader[-2].split()[-1])
             status = reader[-1].split()[-1]
     if fluxflag:
-        df = pd.read_csv(filename, index_col=0)
-        fluxes = df.iloc[solution_index % (len(df)-1)]
+        df = pd.read_csv(filename, index_col=0, sep=';|,|\t', engine='python')
+        if len(df)>1:
+            fluxes = df.iloc[solution_index % (len(df)-1)]
+        elif len(df)==1:
+            fluxes = df.iloc[0]
+        else:
+            raise ValueError('The provided solution file %s does not contain any solutions.' % filename)
         if model is not None:
             fluxes.index = [rxn.id for rxn in model.reactions]
         else:
@@ -77,7 +89,7 @@ def read_solution(filename, model=None, reaction_weights=None, solution_index=0,
             objective_value = calc_objval_from_flux(fluxes, model=model, rw=reaction_weights, eps=eps, thr=thr)
         status = 'flux'
     else:
-        df = pd.read_csv(filename, index_col=0, skipfooter=2, engine='python')
+        df = pd.read_csv(filename, index_col=0, skipfooter=2, sep=';|,|\t', engine='python')
         fluxes = df['fluxes']
         sol_bin = df['binary'].to_list()
     solution = Solution(objective_value, status, fluxes)
@@ -87,6 +99,7 @@ def read_solution(filename, model=None, reaction_weights=None, solution_index=0,
 def calc_objval_from_flux(fluxsol, model, rw, eps=DEFAULT_VALUES['epsilon'], thr=DEFAULT_VALUES['threshold']):
     """
     Calculates the objective value of a solution based on the flux values
+
     Parameters
     ----------
     fluxsol: pandas.Series
@@ -180,10 +193,10 @@ def plot_pca(solution_path, rxn_enum_solutions=None, save=True, save_name=''):
     -------
     pca: sklearn.decomposition.PCA
     """
-    X = pd.read_csv(solution_path, index_col=0)
+    X = pd.read_csv(solution_path, index_col=0, sep=';|,|\t', engine='python')
 
     if rxn_enum_solutions is not None:
-        X2 = pd.read_csv(rxn_enum_solutions, index_col=0)
+        X2 = pd.read_csv(rxn_enum_solutions, index_col=0, sep=';|,|\t', engine='python')
         X_t = pd.concat([X, X2])
     else:
         X_t = X
@@ -204,8 +217,8 @@ def plot_pca(solution_path, rxn_enum_solutions=None, save=True, save_name=''):
     fig, ax = plt.subplots(figsize=(10, 10))
     plt.xticks(fontsize=12)
     plt.yticks(fontsize=14)
-    plt.xlabel('Principal Component 1', fontsize=20)
-    plt.ylabel('Principal Component 2', fontsize=20)
+    plt.xlabel(f'Principal Component 1 (explained variance: {np.around(pca.explained_variance_ratio_[0], 1)}%)', fontsize=20)
+    plt.ylabel(f'Principal Component 2 (explained variance: {np.around(pca.explained_variance_ratio_[1], 1)}%)', fontsize=20)
     plt.title('PCA of enumeration solutions', fontsize=20)
     if rxn_enum_solutions is not None:
         plt.scatter(x2, y2, color='g', label='rxn-enum solutions')
